summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorMarco Lizza <[email protected]>2019-01-10 16:43:21 +0100
committerMarco Lizza <[email protected]>2019-01-10 16:43:21 +0100
commit6056a2a5cf2aa939a10e807e452ed43d4b67f1ce (patch)
tree648bf7c547e4104421ca56312f4ba22bca90569f /src/raylib.h
parentc7437342350168ca1cfa299df33b19cc3859346f (diff)
downloadraylib-6056a2a5cf2aa939a10e807e452ed43d4b67f1ce.tar.gz
raylib-6056a2a5cf2aa939a10e807e452ed43d4b67f1ce.zip
Reworking API upon suggestion.
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 0eda48c3..f5380fbf 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -827,8 +827,9 @@ RLAPI void SetWindowPosition(int x, int y); // Set window
RLAPI void SetWindowMonitor(int monitor); // Set monitor for the current window (fullscreen mode)
RLAPI void SetWindowMinSize(int width, int height); // Set window minimum dimensions (for FLAG_WINDOW_RESIZABLE)
RLAPI void SetWindowSize(int width, int height); // Set window dimensions
-RLAPI void SetWindowVisible(bool visible); // Set window visibility
-RLAPI bool IsWindowVisible(); // Check if window is currently visible
+RLAPI void ShowWindow(); // Show the window
+RLAPI void HideWindow(); // Hide the window
+RLAPI bool IsWindowHidden(); // Check if window is currently hidden
RLAPI int GetScreenWidth(void); // Get current screen width
RLAPI int GetScreenHeight(void); // Get current screen height
RLAPI void *GetWindowHandle(void); // Get native window handle